Index: c/src/lib/libbsp/c4x/c4xsim/ChangeLog
===================================================================
--- c/src/lib/libbsp/c4x/c4xsim/ChangeLog	(revision 6b2923cbc3d60fb3c204677bb0eed2afaedfa0c7)
+++ c/src/lib/libbsp/c4x/c4xsim/ChangeLog	(revision 25c62b02bc8fc9e66c1735e562e91acaa94abbe3)
@@ -1,2 +1,7 @@
+2008-08-31	Joel Sherrill <joel.sherrill@oarcorp.com>
+
+	* timer/timer.c: Eliminate empty function from every benchmark timer
+	driver. Fix spelling.
+
 2008-08-31	Joel Sherrill <joel.sherrill@oarcorp.com>
 
Index: c/src/lib/libbsp/i386/i386ex/ChangeLog
===================================================================
--- c/src/lib/libbsp/i386/i386ex/ChangeLog	(revision 6b2923cbc3d60fb3c204677bb0eed2afaedfa0c7)
+++ c/src/lib/libbsp/i386/i386ex/ChangeLog	(revision 25c62b02bc8fc9e66c1735e562e91acaa94abbe3)
@@ -1,2 +1,7 @@
+2008-08-31	Joel Sherrill <joel.sherrill@oarcorp.com>
+
+	* timer/timer.c: Eliminate empty function from every benchmark timer
+	driver. Fix spelling.
+
 2008-08-31	Joel Sherrill <joel.sherrill@oarcorp.com>
 
Index: c/src/lib/libbsp/i386/i386ex/timer/timer.c
===================================================================
--- c/src/lib/libbsp/i386/i386ex/timer/timer.c	(revision 6b2923cbc3d60fb3c204677bb0eed2afaedfa0c7)
+++ c/src/lib/libbsp/i386/i386ex/timer/timer.c	(revision 25c62b02bc8fc9e66c1735e562e91acaa94abbe3)
@@ -29,5 +29,5 @@
 
 int Ttimer_val;
-rtems_boolean benchmark_timerfind_average_overhead;
+rtems_boolean benchmark_timer_find_average_overhead;
 
 extern void timerisr(void);
@@ -82,5 +82,5 @@
 }
 
-void benchmark_timerinitialize(void)
+void benchmark_timer_initialize(void)
 {
 
@@ -93,5 +93,5 @@
     atexit(Timer_exit); /* Try not to hose the system at exit. */
     if (!i386_set_idt_entry (&timer_raw_irq_data)) {
-      printk("benchmark_timerinitialize: raw handler installation failed\n");
+      printk("benchmark_timer_initialize: raw handler installation failed\n");
       rtems_fatal_error_occurred(1);
     }
@@ -108,5 +108,5 @@
 #define LEAST_VALID       4  /* Don't trust a value lower than this */
 
-int benchmark_timerread(void)
+int benchmark_timer_read(void)
 {
   register uint32_t         clicks;
@@ -125,5 +125,5 @@
   /* ??? Is "do not restore old vector" causing problems? */
 
-  if ( benchmark_timerfind_average_overhead == 1 )
+  if ( benchmark_timer_find_average_overhead == 1 )
     return total;          /* in one microsecond units */
 
@@ -135,13 +135,8 @@
 }
 
-rtems_status_code benchmark_timerempty_function( void )
-{
-  return RTEMS_SUCCESSFUL;
-}
-
-void benchmark_timerdisable_subtracting_average_overhead(
+void benchmark_timer_disable_subtracting_average_overhead(
   rtems_boolean find_flag
 )
 {
-  benchmark_timerfind_average_overhead = find_flag;
+  benchmark_timer_find_average_overhead = find_flag;
 }
Index: c/src/lib/libbsp/i386/pc386/ChangeLog
===================================================================
--- c/src/lib/libbsp/i386/pc386/ChangeLog	(revision 6b2923cbc3d60fb3c204677bb0eed2afaedfa0c7)
+++ c/src/lib/libbsp/i386/pc386/ChangeLog	(revision 25c62b02bc8fc9e66c1735e562e91acaa94abbe3)
@@ -1,2 +1,7 @@
+2008-08-31	Joel Sherrill <joel.sherrill@oarcorp.com>
+
+	* timer/timer.c: Eliminate empty function from every benchmark timer
+	driver. Fix spelling.
+
 2008-08-31	Joel Sherrill <joel.sherrill@oarcorp.com>
 
Index: c/src/lib/libbsp/i386/pc386/timer/timer.c
===================================================================
--- c/src/lib/libbsp/i386/pc386/timer/timer.c	(revision 6b2923cbc3d60fb3c204677bb0eed2afaedfa0c7)
+++ c/src/lib/libbsp/i386/pc386/timer/timer.c	(revision 25c62b02bc8fc9e66c1735e562e91acaa94abbe3)
@@ -60,8 +60,8 @@
 +--------------------------------------------------------------------------*/
 volatile uint32_t         Ttimer_val;
-rtems_boolean    	  benchmark_timerfind_average_overhead = TRUE;
+rtems_boolean    	  benchmark_timer_find_average_overhead = TRUE;
 volatile unsigned int     fastLoop1ms, slowLoop1ms;
-void (*benchmark_timerinitialize_function)(void) = 0;
-uint32_t (*benchmark_timerread_function)(void) = 0;
+void (*benchmark_timer_initialize_function)(void) = 0;
+uint32_t (*benchmark_timer_read_function)(void) = 0;
 void (*Timer_exit_function)(void) = 0;
 
@@ -113,5 +113,5 @@
 
 /*-------------------------------------------------------------------------+
-|         Function: benchmark_timerinitialize
+|         Function: benchmark_timer_initialize
 |      Description: Timer initialization routine.
 | Global Variables: Ttimer_val.
@@ -134,7 +134,7 @@
 
 /*-------------------------------------------------------------------------+
-|         Function: benchmark_timerread
+|         Function: benchmark_timer_read
 |      Description: Read hardware timer value.
-| Global Variables: Ttimer_val, benchmark_timerfind_average_overhead.
+| Global Variables: Ttimer_val, benchmark_timer_find_average_overhead.
 |        Arguments: None.
 |          Returns: Nothing.
@@ -147,5 +147,5 @@
   total =  (uint32_t)(rdtsc() - Ttimer_val);
 
-  if (benchmark_timerfind_average_overhead)
+  if (benchmark_timer_find_average_overhead)
     return total;
   else if (total < LEAST_VALID)
@@ -223,5 +223,5 @@
 
 /*-------------------------------------------------------------------------+
-|         Function: benchmark_timerinitialize
+|         Function: benchmark_timer_initialize
 |      Description: Timer initialization routine.
 | Global Variables: Ttimer_val.
@@ -249,10 +249,10 @@
     continue;
   Ttimer_val = 0;
-} /* benchmark_timerinitialize */
-
-/*-------------------------------------------------------------------------+
-|         Function: benchmark_timerread
+} /* benchmark_timer_initialize */
+
+/*-------------------------------------------------------------------------+
+|         Function: benchmark_timer_read
 |      Description: Read hardware timer value.
-| Global Variables: Ttimer_val, benchmark_timerfind_average_overhead.
+| Global Variables: Ttimer_val, benchmark_timer_find_average_overhead.
 |        Arguments: None.
 |          Returns: Nothing.
@@ -270,5 +270,5 @@
   total  = (Ttimer_val * US_PER_ISR) + (US_PER_ISR - TICK_TO_US(clicks));
 
-  if (benchmark_timerfind_average_overhead)
+  if (benchmark_timer_find_average_overhead)
     return total;
   else if (total < LEAST_VALID)
@@ -284,5 +284,5 @@
 
 void
-benchmark_timerinitialize(void)
+benchmark_timer_initialize(void)
 {
     static rtems_boolean First = TRUE;
@@ -293,6 +293,6 @@
             printk("TSC: timer initialization\n");
 #endif /* DEBUG */
-            benchmark_timerinitialize_function = &tsc_timer_initialize;
-            benchmark_timerread_function = &tsc_read_timer;
+            benchmark_timer_initialize_function = &tsc_timer_initialize;
+            benchmark_timer_read_function = &tsc_read_timer;
             Timer_exit_function = &tsc_timer_exit;
         }
@@ -301,17 +301,17 @@
             printk("ISR: timer initialization\n");
 #endif /* DEBUG */
-            benchmark_timerinitialize_function = &i386_timer_initialize;
-            benchmark_timerread_function = &i386_read_timer;
+            benchmark_timer_initialize_function = &i386_timer_initialize;
+            benchmark_timer_read_function = &i386_read_timer;
             Timer_exit_function = &i386_timer_exit;
         }
         First = FALSE;
     }
-    (*benchmark_timerinitialize_function)();
+    (*benchmark_timer_initialize_function)();
 }
 
 uint32_t
-benchmark_timerread(void)
-{
-    return (*benchmark_timerread_function)();
+benchmark_timer_read(void)
+{
+    return (*benchmark_timer_read_function)();
 }
 
@@ -323,27 +323,15 @@
 
 /*-------------------------------------------------------------------------+
-|         Function: benchmark_timerempty_function
-|      Description: Empty function used in time tests.
-| Global Variables: None.
-|        Arguments: None.
-|          Returns: Nothing.
-+--------------------------------------------------------------------------*/
-rtems_status_code benchmark_timerempty_function(void)
-{
-  return RTEMS_SUCCESSFUL;
-} /* Empty function */
-
-/*-------------------------------------------------------------------------+
-|         Function: benchmark_timerdisable_subtracting_average_overhead
-|      Description: Set internal benchmark_timerfind_average_overhead flag value.
-| Global Variables: benchmark_timerfind_average_overhead.
+|         Function: benchmark_timer_disable_subtracting_average_overhead
+|      Description: Set internal benchmark_timer_find_average_overhead flag value.
+| Global Variables: benchmark_timer_find_average_overhead.
 |        Arguments: find_flag - new value of the flag.
 |          Returns: Nothing.
 +--------------------------------------------------------------------------*/
 void
-benchmark_timerdisable_subtracting_average_overhead(rtems_boolean find_flag)
-{
-  benchmark_timerfind_average_overhead = find_flag;
-} /* benchmark_timerdisable_subtracting_average_overhead */
+benchmark_timer_disable_subtracting_average_overhead(rtems_boolean find_flag)
+{
+  benchmark_timer_find_average_overhead = find_flag;
+} /* benchmark_timer_disable_subtracting_average_overhead */
 
 static unsigned short lastLoadedValue;
Index: c/src/lib/libbsp/i386/ts_386ex/ChangeLog
===================================================================
--- c/src/lib/libbsp/i386/ts_386ex/ChangeLog	(revision 6b2923cbc3d60fb3c204677bb0eed2afaedfa0c7)
+++ c/src/lib/libbsp/i386/ts_386ex/ChangeLog	(revision 25c62b02bc8fc9e66c1735e562e91acaa94abbe3)
@@ -1,2 +1,7 @@
+2008-08-31	Joel Sherrill <joel.sherrill@oarcorp.com>
+
+	* timer/timer.c: Eliminate empty function from every benchmark timer
+	driver. Fix spelling.
+
 2008-08-31	Joel Sherrill <joel.sherrill@oarcorp.com>
 
Index: c/src/lib/libbsp/i386/ts_386ex/timer/timer.c
===================================================================
--- c/src/lib/libbsp/i386/ts_386ex/timer/timer.c	(revision 6b2923cbc3d60fb3c204677bb0eed2afaedfa0c7)
+++ c/src/lib/libbsp/i386/ts_386ex/timer/timer.c	(revision 25c62b02bc8fc9e66c1735e562e91acaa94abbe3)
@@ -29,5 +29,5 @@
 
 volatile uint32_t          Ttimer_val;  /* Updated from ISR!!! */
-rtems_boolean benchmark_timerfind_average_overhead;
+rtems_boolean benchmark_timer_find_average_overhead;
 
 extern void timerisr(void);
@@ -97,5 +97,5 @@
 }
 
-void benchmark_timerinitialize(void)
+void benchmark_timer_initialize(void)
 {
 
@@ -107,10 +107,10 @@
 
     if (!i386_get_current_idt_entry (&old_raw_irq_data)) {
-      printk("benchmark_timerinitialize: failed to get old raw irq entry.\n");
+      printk("benchmark_timer_initialize: failed to get old raw irq entry.\n");
       rtems_fatal_error_occurred(1);
     }
 
     if (!i386_delete_idt_entry (&old_raw_irq_data)) {
-      printk("benchmark_timerinitialize: failed to delete old raw irq entry.\n");
+      printk("benchmark_timer_initialize: failed to delete old raw irq entry.\n");
       rtems_fatal_error_occurred(1);
     }
@@ -118,5 +118,5 @@
     atexit(Timer_exit); /* Try not to hose the system at exit. */
     if (!i386_set_idt_entry (&timer_raw_irq_data)) {
-      printk("benchmark_timerinitialize: raw handler installation failed.\n");
+      printk("benchmark_timer_initialize: raw handler installation failed.\n");
       rtems_fatal_error_occurred(1);
     }
@@ -134,5 +134,5 @@
 #define LEAST_VALID       4  /* Don't trust a value lower than this */
 
-int benchmark_timerread(void)
+int benchmark_timer_read(void)
 {
   register uint32_t         clicks, total;
@@ -156,5 +156,5 @@
   total = Ttimer_val * US_PER_ISR + (US_PER_ISR - clicks);
 
-  if ( benchmark_timerfind_average_overhead == 1 )
+  if ( benchmark_timer_find_average_overhead == 1 )
     return total;          /* in one microsecond units */
   else if ( total < LEAST_VALID )
@@ -164,14 +164,9 @@
 }
 
-rtems_status_code benchmark_timerempty_function( void )
-{
-  return RTEMS_SUCCESSFUL;
-}
-
-void benchmark_timerdisable_subtracting_average_overhead(
+void benchmark_timer_disable_subtracting_average_overhead(
   rtems_boolean find_flag
 )
 {
-  benchmark_timerfind_average_overhead = find_flag;
+  benchmark_timer_find_average_overhead = find_flag;
 }
 
Index: c/src/lib/libbsp/m68k/av5282/ChangeLog
===================================================================
--- c/src/lib/libbsp/m68k/av5282/ChangeLog	(revision 6b2923cbc3d60fb3c204677bb0eed2afaedfa0c7)
+++ c/src/lib/libbsp/m68k/av5282/ChangeLog	(revision 25c62b02bc8fc9e66c1735e562e91acaa94abbe3)
@@ -1,2 +1,7 @@
+2008-08-31	Joel Sherrill <joel.sherrill@oarcorp.com>
+
+	* timer/timer.c: Eliminate empty function from every benchmark timer
+	driver. Fix spelling.
+
 2008-08-31	Joel Sherrill <joel.sherrill@oarcorp.com>
 
Index: c/src/lib/libbsp/m68k/av5282/timer/timer.c
===================================================================
--- c/src/lib/libbsp/m68k/av5282/timer/timer.c	(revision 6b2923cbc3d60fb3c204677bb0eed2afaedfa0c7)
+++ c/src/lib/libbsp/m68k/av5282/timer/timer.c	(revision 25c62b02bc8fc9e66c1735e562e91acaa94abbe3)
@@ -9,5 +9,5 @@
 
 void
-benchmark_timerinitialize(void)
+benchmark_timer_initialize(void)
 {
     int preScaleDivisor = 58;
@@ -23,21 +23,11 @@
  */
 int
-benchmark_timerread(void)
+benchmark_timer_read(void)
 {
     return MCF5282_TIMER3_DTCN;
 }
 
-/*
- *  Empty function call used in loops to measure basic cost of looping
- *  in Timing Test Suite.
- */
-rtems_status_code
-benchmark_timerempty_function(void)
-{
-    return RTEMS_SUCCESSFUL;
-}
-
 void
-benchmark_timerdisable_subtracting_average_overhead(rtems_boolean find_flag)
+benchmark_timer_disable_subtracting_average_overhead(rtems_boolean find_flag)
 {
 }
Index: c/src/lib/libbsp/m68k/gen68360/ChangeLog
===================================================================
--- c/src/lib/libbsp/m68k/gen68360/ChangeLog	(revision 6b2923cbc3d60fb3c204677bb0eed2afaedfa0c7)
+++ c/src/lib/libbsp/m68k/gen68360/ChangeLog	(revision 25c62b02bc8fc9e66c1735e562e91acaa94abbe3)
@@ -1,2 +1,7 @@
+2008-08-31	Joel Sherrill <joel.sherrill@oarcorp.com>
+
+	* timer/timer.c: Eliminate empty function from every benchmark timer
+	driver. Fix spelling.
+
 2008-08-31	Joel Sherrill <joel.sherrill@oarcorp.com>
 
Index: c/src/lib/libbsp/m68k/gen68360/timer/timer.c
===================================================================
--- c/src/lib/libbsp/m68k/gen68360/timer/timer.c	(revision 6b2923cbc3d60fb3c204677bb0eed2afaedfa0c7)
+++ c/src/lib/libbsp/m68k/gen68360/timer/timer.c	(revision 25c62b02bc8fc9e66c1735e562e91acaa94abbe3)
@@ -40,5 +40,5 @@
 
 void
-benchmark_timerinitialize (void)
+benchmark_timer_initialize (void)
 {
 	/*
@@ -74,21 +74,11 @@
  */
 int
-benchmark_timerread (void)
+benchmark_timer_read (void)
 {
 	return *(uint32_t*)&m360.tcn1;
 }
 
-/*
- * Empty function call used in loops to measure basic cost of looping
- * in Timing Test Suite.
- */
-rtems_status_code
-benchmark_timerempty_function (void)
-{
-	return RTEMS_SUCCESSFUL;
-}
-
 void
-benchmark_timerdisable_subtracting_average_overhead(rtems_boolean find_flag)
+benchmark_timer_disable_subtracting_average_overhead(rtems_boolean find_flag)
 {
 }
Index: c/src/lib/libbsp/m68k/genmcf548x/ChangeLog
===================================================================
--- c/src/lib/libbsp/m68k/genmcf548x/ChangeLog	(revision 6b2923cbc3d60fb3c204677bb0eed2afaedfa0c7)
+++ c/src/lib/libbsp/m68k/genmcf548x/ChangeLog	(revision 25c62b02bc8fc9e66c1735e562e91acaa94abbe3)
@@ -1,2 +1,7 @@
+2008-08-31	Joel Sherrill <joel.sherrill@oarcorp.com>
+
+	* timer/timer.c: Eliminate empty function from every benchmark timer
+	driver. Fix spelling.
+
 2008-08-31	Joel Sherrill <joel.sherrill@oarcorp.com>
 
Index: c/src/lib/libbsp/m68k/genmcf548x/timer/timer.c
===================================================================
--- c/src/lib/libbsp/m68k/genmcf548x/timer/timer.c	(revision 6b2923cbc3d60fb3c204677bb0eed2afaedfa0c7)
+++ c/src/lib/libbsp/m68k/genmcf548x/timer/timer.c	(revision 25c62b02bc8fc9e66c1735e562e91acaa94abbe3)
@@ -55,8 +55,8 @@
 #include <mcf548x/mcf548x.h>
 
-rtems_boolean benchmark_timerfind_average_overhead;
+rtems_boolean benchmark_timer_find_average_overhead;
 static uint32_t microsecond_timer_value = 0;
 
-void benchmark_timerinitialize(void)
+void benchmark_timer_initialize(void)
 {
 MCF548X_SLT_SLTCNT1 = 0xFFFFFFFF;
@@ -69,5 +69,5 @@
  */
 int
-benchmark_timerread(void)
+benchmark_timer_read(void)
 {
 	microsecond_timer_value = (0xFFFFFFFF - MCF548X_SLT_SCNT1)/100;
@@ -75,20 +75,7 @@
 }
 
-/*
- *  Empty function call used in loops to measure basic cost of looping
- *  in Timing Test Suite.
- */
-rtems_status_code
-benchmark_timerempty_function(void)
+void
+benchmark_timer_disable_subtracting_average_overhead(rtems_boolean find_flag)
 {
-    return RTEMS_SUCCESSFUL;
+benchmark_timer_find_average_overhead = find_flag;
 }
-
-void
-benchmark_timerdisable_subtracting_average_overhead(rtems_boolean find_flag)
-{
-benchmark_timerfind_average_overhead = find_flag;
-}
-
-
-
Index: c/src/lib/libbsp/m68k/idp/ChangeLog
===================================================================
--- c/src/lib/libbsp/m68k/idp/ChangeLog	(revision 6b2923cbc3d60fb3c204677bb0eed2afaedfa0c7)
+++ c/src/lib/libbsp/m68k/idp/ChangeLog	(revision 25c62b02bc8fc9e66c1735e562e91acaa94abbe3)
@@ -1,2 +1,7 @@
+2008-08-31	Joel Sherrill <joel.sherrill@oarcorp.com>
+
+	* timer/timer.c: Eliminate empty function from every benchmark timer
+	driver. Fix spelling.
+
 2008-08-31	Joel Sherrill <joel.sherrill@oarcorp.com>
 
Index: c/src/lib/libbsp/m68k/idp/timer/timer.c
===================================================================
--- c/src/lib/libbsp/m68k/idp/timer/timer.c	(revision 6b2923cbc3d60fb3c204677bb0eed2afaedfa0c7)
+++ c/src/lib/libbsp/m68k/idp/timer/timer.c	(revision 25c62b02bc8fc9e66c1735e562e91acaa94abbe3)
@@ -33,9 +33,9 @@
 
 int Ttimer_val;
-rtems_boolean benchmark_timerfind_average_overhead;
+rtems_boolean benchmark_timer_find_average_overhead;
 
 rtems_isr timerisr(void);
 
-void benchmark_timerinitialize(void)
+void benchmark_timer_initialize(void)
 {
   (void) set_vector( timerisr, TIMER_VECTOR, 0 );  /* install ISR */
@@ -65,5 +65,5 @@
 #define LEAST_VALID       10 /* Don't trust a value lower than this */
 
-int benchmark_timerread(void)
+int benchmark_timer_read(void)
 {
   uint8_t         data;
@@ -94,5 +94,5 @@
 
   /* do not restore old vector */
-  if ( benchmark_timerfind_average_overhead == 1 )
+  if ( benchmark_timer_find_average_overhead == 1 )
     return total;          /* in countdown units */
 
@@ -106,13 +106,8 @@
 }
 
-rtems_status_code benchmark_timerempty_function( void )
-{
-  return RTEMS_SUCCESSFUL;
-}
-
-void benchmark_timerdisable_subtracting_average_overhead(
+void benchmark_timer_disable_subtracting_average_overhead(
   rtems_boolean find_flag
 )
 {
-  benchmark_timerfind_average_overhead = find_flag;
+  benchmark_timer_find_average_overhead = find_flag;
 }
Index: c/src/lib/libbsp/m68k/mcf52235/ChangeLog
===================================================================
--- c/src/lib/libbsp/m68k/mcf52235/ChangeLog	(revision 6b2923cbc3d60fb3c204677bb0eed2afaedfa0c7)
+++ c/src/lib/libbsp/m68k/mcf52235/ChangeLog	(revision 25c62b02bc8fc9e66c1735e562e91acaa94abbe3)
@@ -1,2 +1,7 @@
+2008-08-31	Joel Sherrill <joel.sherrill@oarcorp.com>
+
+	* timer/timer.c: Eliminate empty function from every benchmark timer
+	driver. Fix spelling.
+
 2008-08-31	Joel Sherrill <joel.sherrill@oarcorp.com>
 
Index: c/src/lib/libbsp/m68k/mcf52235/timer/timer.c
===================================================================
--- c/src/lib/libbsp/m68k/mcf52235/timer/timer.c	(revision 6b2923cbc3d60fb3c204677bb0eed2afaedfa0c7)
+++ c/src/lib/libbsp/m68k/mcf52235/timer/timer.c	(revision 25c62b02bc8fc9e66c1735e562e91acaa94abbe3)
@@ -17,5 +17,5 @@
 #include <bsp.h>
 
-void benchmark_timerinitialize(void)
+void benchmark_timer_initialize(void)
 {
   uint32_t preScaleDivisor = bsp_get_CPU_clock_speed() / 1000000;
@@ -29,19 +29,10 @@
  * Return timer value in microsecond units
  */
-int benchmark_timerread(void)
+int benchmark_timer_read(void)
 {
   return MCF_DTIM3_DTCN;
 }
 
-/*
- *  Empty function call used in loops to measure basic cost of looping
- *  in Timing Test Suite.
- */
-rtems_status_code benchmark_timerempty_function(void)
-{
-  return RTEMS_SUCCESSFUL;
-}
-
-void benchmark_timerdisable_subtracting_average_overhead(rtems_boolean find_flag)
+void benchmark_timer_disable_subtracting_average_overhead(rtems_boolean find_flag)
 {
 }
Index: c/src/lib/libbsp/m68k/mcf5235/ChangeLog
===================================================================
--- c/src/lib/libbsp/m68k/mcf5235/ChangeLog	(revision 6b2923cbc3d60fb3c204677bb0eed2afaedfa0c7)
+++ c/src/lib/libbsp/m68k/mcf5235/ChangeLog	(revision 25c62b02bc8fc9e66c1735e562e91acaa94abbe3)
@@ -1,2 +1,7 @@
+2008-08-31	Joel Sherrill <joel.sherrill@oarcorp.com>
+
+	* timer/timer.c: Eliminate empty function from every benchmark timer
+	driver. Fix spelling.
+
 2008-08-31	Joel Sherrill <joel.sherrill@oarcorp.com>
 
Index: c/src/lib/libbsp/m68k/mcf5235/timer/timer.c
===================================================================
--- c/src/lib/libbsp/m68k/mcf5235/timer/timer.c	(revision 6b2923cbc3d60fb3c204677bb0eed2afaedfa0c7)
+++ c/src/lib/libbsp/m68k/mcf5235/timer/timer.c	(revision 25c62b02bc8fc9e66c1735e562e91acaa94abbe3)
@@ -9,5 +9,5 @@
 
 void
-benchmark_timerinitialize(void)
+benchmark_timer_initialize(void)
 {
     int preScaleDivisor = 0x4A;
@@ -23,21 +23,11 @@
  */
 int
-benchmark_timerread(void)
+benchmark_timer_read(void)
 {
     return MCF5235_TIMER3_DTCN;
 }
 
-/*
- *  Empty function call used in loops to measure basic cost of looping
- *  in Timing Test Suite.
- */
-rtems_status_code
-benchmark_timerempty_function(void)
-{
-    return RTEMS_SUCCESSFUL;
-}
-
 void
-benchmark_timerdisable_subtracting_average_overhead(rtems_boolean find_flag)
+benchmark_timer_disable_subtracting_average_overhead(rtems_boolean find_flag)
 {
 }
Index: c/src/lib/libbsp/m68k/mcf5329/ChangeLog
===================================================================
--- c/src/lib/libbsp/m68k/mcf5329/ChangeLog	(revision 6b2923cbc3d60fb3c204677bb0eed2afaedfa0c7)
+++ c/src/lib/libbsp/m68k/mcf5329/ChangeLog	(revision 25c62b02bc8fc9e66c1735e562e91acaa94abbe3)
@@ -1,2 +1,7 @@
+2008-08-31	Joel Sherrill <joel.sherrill@oarcorp.com>
+
+	* timer/timer.c: Eliminate empty function from every benchmark timer
+	driver. Fix spelling.
+
 2008-08-31	Joel Sherrill <joel.sherrill@oarcorp.com>
 
Index: c/src/lib/libbsp/m68k/mcf5329/timer/timer.c
===================================================================
--- c/src/lib/libbsp/m68k/mcf5329/timer/timer.c	(revision 6b2923cbc3d60fb3c204677bb0eed2afaedfa0c7)
+++ c/src/lib/libbsp/m68k/mcf5329/timer/timer.c	(revision 25c62b02bc8fc9e66c1735e562e91acaa94abbe3)
@@ -18,5 +18,5 @@
 #include <bsp.h>
 
-void benchmark_timerinitialize(void)
+void benchmark_timer_initialize(void)
 {
   uint32_t preScaleDivisor = bsp_get_BUS_clock_speed() / 1000000;
@@ -30,19 +30,10 @@
  * Return timer value in microsecond units
  */
-int benchmark_timerread(void)
+int benchmark_timer_read(void)
 {
   return MCF_DTIM3_DTCN;
 }
 
-/*
- *  Empty function call used in loops to measure basic cost of looping
- *  in Timing Test Suite.
- */
-rtems_status_code benchmark_timerempty_function(void)
-{
-  return RTEMS_SUCCESSFUL;
-}
-
-void benchmark_timerdisable_subtracting_average_overhead(rtems_boolean find_flag)
+void benchmark_timer_disable_subtracting_average_overhead(rtems_boolean find_flag)
 {
 }
Index: c/src/lib/libbsp/m68k/mrm332/ChangeLog
===================================================================
--- c/src/lib/libbsp/m68k/mrm332/ChangeLog	(revision 6b2923cbc3d60fb3c204677bb0eed2afaedfa0c7)
+++ c/src/lib/libbsp/m68k/mrm332/ChangeLog	(revision 25c62b02bc8fc9e66c1735e562e91acaa94abbe3)
@@ -1,2 +1,7 @@
+2008-08-31	Joel Sherrill <joel.sherrill@oarcorp.com>
+
+	* timer/timer.c: Eliminate empty function from every benchmark timer
+	driver. Fix spelling.
+
 2008-08-31	Joel Sherrill <joel.sherrill@oarcorp.com>
 
Index: c/src/lib/libbsp/m68k/mvme136/ChangeLog
===================================================================
--- c/src/lib/libbsp/m68k/mvme136/ChangeLog	(revision 6b2923cbc3d60fb3c204677bb0eed2afaedfa0c7)
+++ c/src/lib/libbsp/m68k/mvme136/ChangeLog	(revision 25c62b02bc8fc9e66c1735e562e91acaa94abbe3)
@@ -1,2 +1,7 @@
+2008-08-31	Joel Sherrill <joel.sherrill@oarcorp.com>
+
+	* timer/timer.c: Eliminate empty function from every benchmark timer
+	driver. Fix spelling.
+
 2008-08-31	Joel Sherrill <joel.sherrill@oarcorp.com>
 
Index: c/src/lib/libbsp/m68k/mvme136/timer/timer.c
===================================================================
--- c/src/lib/libbsp/m68k/mvme136/timer/timer.c	(revision 6b2923cbc3d60fb3c204677bb0eed2afaedfa0c7)
+++ c/src/lib/libbsp/m68k/mvme136/timer/timer.c	(revision 25c62b02bc8fc9e66c1735e562e91acaa94abbe3)
@@ -30,9 +30,9 @@
 
 int Ttimer_val;
-rtems_boolean benchmark_timerfind_average_overhead;
+rtems_boolean benchmark_timer_find_average_overhead;
 
 rtems_isr timerisr(void);
 
-void benchmark_timerinitialize(void)
+void benchmark_timer_initialize(void)
 {
   (void) set_vector( timerisr, 66, 0 );       /* install ISR */
@@ -66,5 +66,5 @@
 #define LEAST_VALID       10 /* Don't trust a value lower than this */
 
-int benchmark_timerread(void)
+int benchmark_timer_read(void)
 {
 /*
@@ -83,5 +83,5 @@
   total = (Ttimer_val * 0x10000) + remaining;
 
-  if ( benchmark_timerfind_average_overhead == 1 )
+  if ( benchmark_timer_find_average_overhead == 1 )
     return total;          /* in one-half microsecond units */
 
@@ -93,13 +93,8 @@
 }
 
-rtems_status_code benchmark_timerempty_function( void )
-{
-  return RTEMS_SUCCESSFUL;
-}
-
-void benchmark_timerdisable_subtracting_average_overhead(
+void benchmark_timer_disable_subtracting_average_overhead(
   rtems_boolean find_flag
 )
 {
-  benchmark_timerfind_average_overhead = find_flag;
+  benchmark_timer_find_average_overhead = find_flag;
 }
Index: c/src/lib/libbsp/m68k/mvme147/ChangeLog
===================================================================
--- c/src/lib/libbsp/m68k/mvme147/ChangeLog	(revision 6b2923cbc3d60fb3c204677bb0eed2afaedfa0c7)
+++ c/src/lib/libbsp/m68k/mvme147/ChangeLog	(revision 25c62b02bc8fc9e66c1735e562e91acaa94abbe3)
@@ -1,2 +1,7 @@
+2008-08-31	Joel Sherrill <joel.sherrill@oarcorp.com>
+
+	* timer/timer.c: Eliminate empty function from every benchmark timer
+	driver. Fix spelling.
+
 2008-08-31	Joel Sherrill <joel.sherrill@oarcorp.com>
 
Index: c/src/lib/libbsp/m68k/mvme147/timer/timer.c
===================================================================
--- c/src/lib/libbsp/m68k/mvme147/timer/timer.c	(revision 6b2923cbc3d60fb3c204677bb0eed2afaedfa0c7)
+++ c/src/lib/libbsp/m68k/mvme147/timer/timer.c	(revision 25c62b02bc8fc9e66c1735e562e91acaa94abbe3)
@@ -33,9 +33,9 @@
 
 int Ttimer_val;
-rtems_boolean benchmark_timerfind_average_overhead;
+rtems_boolean benchmark_timer_find_average_overhead;
 
 rtems_isr timerisr(void);
 
-void benchmark_timerinitialize(void)
+void benchmark_timer_initialize(void)
 {
   (void) set_vector(timerisr, TIMER_1_VECTOR, 0); /* install ISR */
@@ -57,5 +57,5 @@
 #define LEAST_VALID       10 /* Don't trust a value lower than this */
 
-int benchmark_timerread(void)
+int benchmark_timer_read(void)
 {
   uint32_t         total;
@@ -71,13 +71,8 @@
 }
 
-rtems_status_code benchmark_timerempty_function( void )
-{
-  return RTEMS_SUCCESSFUL;
-}
-
-void benchmark_timerdisable_subtracting_average_overhead(
+void benchmark_timer_disable_subtracting_average_overhead(
   rtems_boolean find_flag
 )
 {
-  benchmark_timerfind_average_overhead = find_flag;
+  benchmark_timer_find_average_overhead = find_flag;
 }
Index: c/src/lib/libbsp/m68k/mvme162/ChangeLog
===================================================================
--- c/src/lib/libbsp/m68k/mvme162/ChangeLog	(revision 6b2923cbc3d60fb3c204677bb0eed2afaedfa0c7)
+++ c/src/lib/libbsp/m68k/mvme162/ChangeLog	(revision 25c62b02bc8fc9e66c1735e562e91acaa94abbe3)
@@ -1,2 +1,7 @@
+2008-08-31	Joel Sherrill <joel.sherrill@oarcorp.com>
+
+	* timer/timer.c: Eliminate empty function from every benchmark timer
+	driver. Fix spelling.
+
 2008-08-31	Joel Sherrill <joel.sherrill@oarcorp.com>
 
Index: c/src/lib/libbsp/m68k/mvme162/timer/timer.c
===================================================================
--- c/src/lib/libbsp/m68k/mvme162/timer/timer.c	(revision 6b2923cbc3d60fb3c204677bb0eed2afaedfa0c7)
+++ c/src/lib/libbsp/m68k/mvme162/timer/timer.c	(revision 25c62b02bc8fc9e66c1735e562e91acaa94abbe3)
@@ -39,9 +39,9 @@
 
 uint32_t            Ttimer_val;
-rtems_boolean       benchmark_timerfind_average_overhead;
+rtems_boolean       benchmark_timer_find_average_overhead;
 
 rtems_isr timerisr(void);
 
-void benchmark_timerinitialize(void)
+void benchmark_timer_initialize(void)
 {
   (void) set_vector( timerisr, VBR0 * 0x10 + 0x8, 0 );
@@ -64,5 +64,5 @@
 #define LEAST_VALID       10U   /* Don't trust a value lower than this */
 
-int benchmark_timerread(void)
+int benchmark_timer_read(void)
 {
   uint32_t            total;
@@ -70,5 +70,5 @@
   total = (Ttimer_val * TICK_INTERVAL) + lcsr->timer_cnt_1;
 
-  if ( benchmark_timerfind_average_overhead == 1 )
+  if ( benchmark_timer_find_average_overhead == 1 )
     return total;          /* in one-half microsecond units */
 
@@ -79,13 +79,8 @@
 }
 
-rtems_status_code benchmark_timerempty_function( void )
-{
-  return RTEMS_SUCCESSFUL;
-}
-
-void benchmark_timerdisable_subtracting_average_overhead(
+void benchmark_timer_disable_subtracting_average_overhead(
   rtems_boolean find_flag
 )
 {
-  benchmark_timerfind_average_overhead = find_flag;
+  benchmark_timer_find_average_overhead = find_flag;
 }
Index: c/src/lib/libbsp/m68k/uC5282/ChangeLog
===================================================================
--- c/src/lib/libbsp/m68k/uC5282/ChangeLog	(revision 6b2923cbc3d60fb3c204677bb0eed2afaedfa0c7)
+++ c/src/lib/libbsp/m68k/uC5282/ChangeLog	(revision 25c62b02bc8fc9e66c1735e562e91acaa94abbe3)
@@ -1,2 +1,7 @@
+2008-08-31	Joel Sherrill <joel.sherrill@oarcorp.com>
+
+	* timer/timer.c: Eliminate empty function from every benchmark timer
+	driver. Fix spelling.
+
 2008-08-31	Joel Sherrill <joel.sherrill@oarcorp.com>
 
Index: c/src/lib/libbsp/m68k/uC5282/timer/timer.c
===================================================================
--- c/src/lib/libbsp/m68k/uC5282/timer/timer.c	(revision 6b2923cbc3d60fb3c204677bb0eed2afaedfa0c7)
+++ c/src/lib/libbsp/m68k/uC5282/timer/timer.c	(revision 25c62b02bc8fc9e66c1735e562e91acaa94abbe3)
@@ -18,5 +18,5 @@
 
 void
-benchmark_timerinitialize(void)
+benchmark_timer_initialize(void)
 {
     int preScaleDivisor = bsp_get_CPU_clock_speed() / 1000000;
@@ -36,21 +36,11 @@
  */
 int
-benchmark_timerread(void)
+benchmark_timer_read(void)
 {
     return MCF5282_TIMER3_DTCN;
 }
 
-/*
- *  Empty function call used in loops to measure basic cost of looping
- *  in Timing Test Suite.
- */
-rtems_status_code
-benchmark_timerempty_function(void)
-{
-    return RTEMS_SUCCESSFUL;
-}
-
 void
-benchmark_timerdisable_subtracting_average_overhead(rtems_boolean find_flag)
+benchmark_timer_disable_subtracting_average_overhead(rtems_boolean find_flag)
 {
 }
Index: c/src/lib/libbsp/mips/csb350/ChangeLog
===================================================================
--- c/src/lib/libbsp/mips/csb350/ChangeLog	(revision 6b2923cbc3d60fb3c204677bb0eed2afaedfa0c7)
+++ c/src/lib/libbsp/mips/csb350/ChangeLog	(revision 25c62b02bc8fc9e66c1735e562e91acaa94abbe3)
@@ -1,2 +1,7 @@
+2008-08-31	Joel Sherrill <joel.sherrill@oarcorp.com>
+
+	* timer/timer.c: Eliminate empty function from every benchmark timer
+	driver. Fix spelling.
+
 2008-08-31	Joel Sherrill <joel.sherrill@oarcorp.com>
 
Index: c/src/lib/libbsp/mips/csb350/timer/timer.c
===================================================================
--- c/src/lib/libbsp/mips/csb350/timer/timer.c	(revision 6b2923cbc3d60fb3c204677bb0eed2afaedfa0c7)
+++ c/src/lib/libbsp/mips/csb350/timer/timer.c	(revision 25c62b02bc8fc9e66c1735e562e91acaa94abbe3)
@@ -17,8 +17,8 @@
 #include <bsp.h>
 
-rtems_boolean benchmark_timerfind_average_overhead;
+rtems_boolean benchmark_timer_find_average_overhead;
 uint32_t tstart;
 
-void benchmark_timerinitialize(void)
+void benchmark_timer_initialize(void)
 {
     asm volatile ("mfc0 %0, $9\n" : "=r" (tstart));
@@ -31,5 +31,5 @@
                              /* tx39 simulator can count instructions. :) */
 
-int benchmark_timerread(void)
+int benchmark_timer_read(void)
 {
   uint32_t  total;
@@ -42,5 +42,5 @@
 
 
-  if ( benchmark_timerfind_average_overhead == 1 )
+  if ( benchmark_timer_find_average_overhead == 1 )
     return total;          /* in one microsecond units */
 
@@ -51,13 +51,8 @@
 }
 
-rtems_status_code benchmark_timerempty_function( void )
-{
-  return RTEMS_SUCCESSFUL;
-}
-
-void benchmark_timerdisable_subtracting_average_overhead(
+void benchmark_timer_disable_subtracting_average_overhead(
   rtems_boolean find_flag
 )
 {
-  benchmark_timerfind_average_overhead = find_flag;
+  benchmark_timer_find_average_overhead = find_flag;
 }
Index: c/src/lib/libbsp/mips/genmongoosev/ChangeLog
===================================================================
--- c/src/lib/libbsp/mips/genmongoosev/ChangeLog	(revision 6b2923cbc3d60fb3c204677bb0eed2afaedfa0c7)
+++ c/src/lib/libbsp/mips/genmongoosev/ChangeLog	(revision 25c62b02bc8fc9e66c1735e562e91acaa94abbe3)
@@ -1,2 +1,7 @@
+2008-08-31	Joel Sherrill <joel.sherrill@oarcorp.com>
+
+	* timer/timer.c: Eliminate empty function from every benchmark timer
+	driver. Fix spelling.
+
 2008-08-31	Joel Sherrill <joel.sherrill@oarcorp.com>
 
Index: c/src/lib/libbsp/mips/genmongoosev/timer/timer.c
===================================================================
--- c/src/lib/libbsp/mips/genmongoosev/timer/timer.c	(revision 6b2923cbc3d60fb3c204677bb0eed2afaedfa0c7)
+++ c/src/lib/libbsp/mips/genmongoosev/timer/timer.c	(revision 25c62b02bc8fc9e66c1735e562e91acaa94abbe3)
@@ -16,5 +16,5 @@
 #include <bsp.h>
 
-rtems_boolean benchmark_timerfind_average_overhead;
+rtems_boolean benchmark_timer_find_average_overhead;
 
 #if defined(USE_TIMER2_FOR_CLOCK)
@@ -26,5 +26,5 @@
 #endif
 
-void benchmark_timerinitialize(void)
+void benchmark_timer_initialize(void)
 {
   /*
@@ -57,5 +57,5 @@
 #include <rtems/bspIo.h>
 
-int benchmark_timerread(void)
+int benchmark_timer_read(void)
 {
   uint32_t          clicks;
@@ -76,5 +76,5 @@
     printk( "MG5 timer overran\n" );
 
-  if ( benchmark_timerfind_average_overhead == 1 )
+  if ( benchmark_timer_find_average_overhead == 1 )
     return total;          /* in cycle units */
 
@@ -85,14 +85,9 @@
 }
 
-rtems_status_code benchmark_timerempty_function( void )
-{
-  return RTEMS_SUCCESSFUL;
-}
-
-void benchmark_timerdisable_subtracting_average_overhead(
+void benchmark_timer_disable_subtracting_average_overhead(
   rtems_boolean find_flag
 )
 {
-  benchmark_timerfind_average_overhead = find_flag;
+  benchmark_timer_find_average_overhead = find_flag;
 }
 
Index: c/src/lib/libbsp/mips/jmr3904/ChangeLog
===================================================================
--- c/src/lib/libbsp/mips/jmr3904/ChangeLog	(revision 6b2923cbc3d60fb3c204677bb0eed2afaedfa0c7)
+++ c/src/lib/libbsp/mips/jmr3904/ChangeLog	(revision 25c62b02bc8fc9e66c1735e562e91acaa94abbe3)
@@ -1,2 +1,7 @@
+2008-08-31	Joel Sherrill <joel.sherrill@oarcorp.com>
+
+	* timer/timer.c: Eliminate empty function from every benchmark timer
+	driver. Fix spelling.
+
 2008-08-31	Joel Sherrill <joel.sherrill@oarcorp.com>
 
Index: c/src/lib/libbsp/mips/jmr3904/timer/timer.c
===================================================================
--- c/src/lib/libbsp/mips/jmr3904/timer/timer.c	(revision 6b2923cbc3d60fb3c204677bb0eed2afaedfa0c7)
+++ c/src/lib/libbsp/mips/jmr3904/timer/timer.c	(revision 25c62b02bc8fc9e66c1735e562e91acaa94abbe3)
@@ -18,7 +18,7 @@
 #include <bsp.h>
 
-rtems_boolean benchmark_timerfind_average_overhead;
+rtems_boolean benchmark_timer_find_average_overhead;
 
-void benchmark_timerinitialize(void)
+void benchmark_timer_initialize(void)
 {
   /*
@@ -46,5 +46,5 @@
                              /* tx39 simulator can count instructions. :) */
 
-int benchmark_timerread(void)
+int benchmark_timer_read(void)
 {
   uint32_t          total;
@@ -52,5 +52,5 @@
   total = TX3904_TIMER_READ( TX3904_TIMER1_BASE, TX3904_TIMER_TRR );
 
-  if ( benchmark_timerfind_average_overhead == 1 )
+  if ( benchmark_timer_find_average_overhead == 1 )
     return total;          /* in one microsecond units */
 
@@ -61,13 +61,8 @@
 }
 
-rtems_status_code benchmark_timerempty_function( void )
-{
-  return RTEMS_SUCCESSFUL;
-}
-
-void benchmark_timerdisable_subtracting_average_overhead(
+void benchmark_timer_disable_subtracting_average_overhead(
   rtems_boolean find_flag
 )
 {
-  benchmark_timerfind_average_overhead = find_flag;
+  benchmark_timer_find_average_overhead = find_flag;
 }
Index: c/src/lib/libbsp/nios2/nios2_iss/ChangeLog
===================================================================
--- c/src/lib/libbsp/nios2/nios2_iss/ChangeLog	(revision 6b2923cbc3d60fb3c204677bb0eed2afaedfa0c7)
+++ c/src/lib/libbsp/nios2/nios2_iss/ChangeLog	(revision 25c62b02bc8fc9e66c1735e562e91acaa94abbe3)
@@ -1,2 +1,7 @@
+2008-08-31	Joel Sherrill <joel.sherrill@oarcorp.com>
+
+	* timer/timer.c: Eliminate empty function from every benchmark timer
+	driver. Fix spelling.
+
 2008-08-31	Joel Sherrill <joel.sherrill@oarcorp.com>
 
Index: c/src/lib/libbsp/powerpc/score603e/ChangeLog
===================================================================
--- c/src/lib/libbsp/powerpc/score603e/ChangeLog	(revision 6b2923cbc3d60fb3c204677bb0eed2afaedfa0c7)
+++ c/src/lib/libbsp/powerpc/score603e/ChangeLog	(revision 25c62b02bc8fc9e66c1735e562e91acaa94abbe3)
@@ -1,2 +1,7 @@
+2008-08-31	Joel Sherrill <joel.sherrill@oarcorp.com>
+
+	* timer/timer.c: Eliminate empty function from every benchmark timer
+	driver. Fix spelling.
+
 2008-08-31	Joel Sherrill <joel.sherrill@oarcorp.com>
 
Index: c/src/lib/libbsp/powerpc/score603e/timer/timer.c
===================================================================
--- c/src/lib/libbsp/powerpc/score603e/timer/timer.c	(revision 6b2923cbc3d60fb3c204677bb0eed2afaedfa0c7)
+++ c/src/lib/libbsp/powerpc/score603e/timer/timer.c	(revision 25c62b02bc8fc9e66c1735e562e91acaa94abbe3)
@@ -24,11 +24,11 @@
 uint64_t         Timer_driver_Start_time;
 
-rtems_boolean benchmark_timerfind_average_overhead;
+rtems_boolean benchmark_timer_find_average_overhead;
 
 /*
- * benchmark_timerinitialize
+ * benchmark_timer_initialize
  */
 
-void benchmark_timerinitialize()
+void benchmark_timer_initialize()
 {
 
@@ -41,8 +41,8 @@
 
 /*
- *  benchmark_timerread
+ *  benchmark_timer_read
  */
 
-int benchmark_timerread()
+int benchmark_timer_read()
 {
   uint64_t          clicks;
@@ -62,5 +62,5 @@
   total = (uint32_t) total64;
 
-  if ( benchmark_timerfind_average_overhead == 1 )
+  if ( benchmark_timer_find_average_overhead == 1 )
     return total;          /* in "clicks" of the decrementer units */
 
@@ -71,13 +71,8 @@
 }
 
-rtems_status_code benchmark_timerempty_function( void )
-{
-  return RTEMS_SUCCESSFUL;
-}
-
-void benchmark_timerdisable_subtracting_average_overhead(
+void benchmark_timer_disable_subtracting_average_overhead(
   rtems_boolean find_flag
 )
 {
-  benchmark_timerfind_average_overhead = find_flag;
+  benchmark_timer_find_average_overhead = find_flag;
 }
Index: c/src/lib/libbsp/sh/simsh4/ChangeLog
===================================================================
--- c/src/lib/libbsp/sh/simsh4/ChangeLog	(revision 6b2923cbc3d60fb3c204677bb0eed2afaedfa0c7)
+++ c/src/lib/libbsp/sh/simsh4/ChangeLog	(revision 25c62b02bc8fc9e66c1735e562e91acaa94abbe3)
@@ -1,2 +1,7 @@
+2008-08-31	Joel Sherrill <joel.sherrill@oarcorp.com>
+
+	* timer/timer.c: Eliminate empty function from every benchmark timer
+	driver. Fix spelling.
+
 2008-08-31	Joel Sherrill <joel.sherrill@oarcorp.com>
 
Index: c/src/lib/libbsp/c4x/c4xsim/timer/timer.c
===================================================================
--- c/src/lib/libbsp/c4x/c4xsim/timer/timer.c	(revision 6b2923cbc3d60fb3c204677bb0eed2afaedfa0c7)
+++ c/src/lib/libbsp/c4x/c4xsim/timer/timer.c	(revision 25c62b02bc8fc9e66c1735e562e91acaa94abbe3)
@@ -3,6 +3,6 @@
  *  This file manages the benchmark timer used by the RTEMS Timing Test
  *  Suite.  Each measured time period is demarcated by calls to
  *  benchmark_timerinitialize() and benchmark_timerread().  benchmark_timerread() usually returns
  *  the number of microseconds since benchmark_timerinitialize() exitted.
  *
  *  NOTE: It is important that the timer start/stop overhead be
@@ -24,9 +24,9 @@
 
 uint32_t         Timer_interrupts;
-rtems_boolean benchmark_timerfind_average_overhead;
+rtems_boolean benchmark_timer_find_average_overhead;
 
 static uint32_t   start;
 
-void benchmark_timerinitialize( void )
+void benchmark_timer_initialize( void )
 {
 
@@ -49,5 +49,5 @@
 
 /*
  *  The following controls the behavior of benchmark_timerread().
  *
  *  AVG_OVEREHAD is the overhead for starting and stopping the timer.  It
@@ -63,5 +63,5 @@
 #define LEAST_VALID       1  /* Don't trust a clicks value lower than this */
 
-int benchmark_timerread( void )
+int benchmark_timer_read( void )
 {
   uint32_t         clicks;
@@ -84,5 +84,5 @@
   total = clicks * 1;
 
-  if ( benchmark_timerfind_average_overhead == 1 ) {
+  if ( benchmark_timer_find_average_overhead == 1 ) {
     return total;          /* in count units where each count is */
                            /* 1 / (clock frequency/2) */
@@ -98,18 +98,8 @@
 }
 
-/*
- *  Empty function call used in loops to measure basic cost of looping
- *  in Timing Test Suite.
- */
-
-rtems_status_code benchmark_timerempty_function( void )
-{
-  return RTEMS_SUCCESSFUL;
-}
-
-void benchmark_timerdisable_subtracting_average_overhead(
+void benchmark_timer_disable_subtracting_average_overhead(
   rtems_boolean find_flag
 )
 {
-  benchmark_timerfind_average_overhead = find_flag;
+  benchmark_timer_find_average_overhead = find_flag;
 }
@@ -3,6 +3,6 @@
  *  This file manages the benchmark timer used by the RTEMS Timing Test
  *  Suite.  Each measured time period is demarcated by calls to
- *  benchmark_timerinitialize() and benchmark_timerread().  benchmark_timerread() usually returns
- *  the number of microseconds since benchmark_timerinitialize() exitted.
+ *  benchmark_timer_initialize() and benchmark_timer_read().  benchmark_timer_read() usually returns
+ *  the number of microseconds since benchmark_timer_initialize() exitted.
  *
  *  NOTE: It is important that the timer start/stop overhead be
@@ -49,5 +49,5 @@
 
 /*
- *  The following controls the behavior of benchmark_timerread().
+ *  The following controls the behavior of benchmark_timer_read().
  *
  *  AVG_OVEREHAD is the overhead for starting and stopping the timer.  It
Index: c/src/lib/libbsp/m68k/mrm332/timer/timer.c
===================================================================
--- c/src/lib/libbsp/m68k/mrm332/timer/timer.c	(revision 6b2923cbc3d60fb3c204677bb0eed2afaedfa0c7)
+++ c/src/lib/libbsp/m68k/mrm332/timer/timer.c	(revision 25c62b02bc8fc9e66c1735e562e91acaa94abbe3)
@@ -22,14 +22,14 @@
 #include <bsp.h>
 
-rtems_boolean benchmark_timerfind_average_overhead;
+rtems_boolean benchmark_timer_find_average_overhead;
 
 extern rtems_isr Clock_isr(void);
 
-void benchmark_timerinitialize( void )
+void benchmark_timer_initialize( void )
 {
 }
 
 /*
  *  The following controls the behavior of benchmark_timerread().
  *
  *  FIND_AVG_OVERHEAD *  instructs the routine to return the "raw" count.
@@ -50,10 +50,10 @@
  * Return timer value in 1/2-microsecond units
  */
-int benchmark_timerread( void )
+int benchmark_timer_read( void )
 {
   uint32_t         total;
   total = 0;
 
-  if ( benchmark_timerfind_average_overhead == 1 )
+  if ( benchmark_timer_find_average_overhead == 1 )
     return total;          /* in XXX microsecond units */
 
@@ -64,18 +64,8 @@
 }
 
-/*
- *  Empty function call used in loops to measure basic cost of looping
- *  in Timing Test Suite.
- */
-
-rtems_status_code benchmark_timerempty_function(void)
-{
-    return RTEMS_SUCCESSFUL;
-}
-
-void benchmark_timerdisable_subtracting_average_overhead(
+void benchmark_timer_disable_subtracting_average_overhead(
   rtems_boolean find_flag
 )
 {
-  benchmark_timerfind_average_overhead = find_flag;
+  benchmark_timer_find_average_overhead = find_flag;
 }
@@ -22,14 +22,14 @@
 
 /*
- *  The following controls the behavior of benchmark_timerread().
+ *  The following controls the behavior of benchmark_timer_read().
  *
  *  FIND_AVG_OVERHEAD *  instructs the routine to return the "raw" count.
Index: c/src/lib/libbsp/nios2/nios2_iss/timer/timer.c
===================================================================
--- c/src/lib/libbsp/nios2/nios2_iss/timer/timer.c	(revision 6b2923cbc3d60fb3c204677bb0eed2afaedfa0c7)
+++ c/src/lib/libbsp/nios2/nios2_iss/timer/timer.c	(revision 25c62b02bc8fc9e66c1735e562e91acaa94abbe3)
@@ -3,6 +3,6 @@
  *  This file manages the benchmark timer used by the RTEMS Timing Test
  *  Suite.  Each measured time period is demarcated by calls to
  *  benchmark_timerinitialize() and benchmark_timerread().  benchmark_timerread() usually returns
  *  the number of microseconds since benchmark_timerinitialize() exitted.
  *
  *  NOTE: It is important that the timer start/stop overhead be
@@ -28,5 +28,5 @@
 
 volatile uint32_t Timer_interrupts;
-rtems_boolean    benchmark_timerfind_average_overhead;
+rtems_boolean    benchmark_timer_find_average_overhead;
 
 #define TIMER_REGS ((altera_avalon_timer_regs*)NIOS2_IO_BASE(TIMER_BASE))
@@ -38,5 +38,5 @@
 }
 
-void benchmark_timerinitialize( void )
+void benchmark_timer_initialize( void )
 {
   uint32_t old_ie;
@@ -84,5 +84,5 @@
 
 /*
  *  The following controls the behavior of benchmark_timerread().
  *
  *  AVG_OVEREHAD is the overhead for starting and stopping the timer.  It
@@ -98,5 +98,5 @@
 #define LEAST_VALID AVG_OVERHEAD /* Don't trust a value lower than this */
 
-int benchmark_timerread( void )
+int benchmark_timer_read( void )
 {
   uint32_t timer_wraps;
@@ -129,23 +129,13 @@
   if(total < LEAST_VALID) return 0;
 
-  if(benchmark_timerfind_average_overhead != TRUE) total-= AVG_OVERHEAD;
+  if(benchmark_timer_find_average_overhead != TRUE) total-= AVG_OVERHEAD;
  
   return total;
 }
 
-/*
- *  Empty function call used in loops to measure basic cost of looping
- *  in Timing Test Suite.
- */
-
-rtems_status_code benchmark_timerempty_function( void )
-{
-  return RTEMS_SUCCESSFUL;
-}
-
-void benchmark_timerdisable_subtracting_average_overhead(
+void benchmark_timer_disable_subtracting_average_overhead(
   rtems_boolean find_flag
 )
 {
-  benchmark_timerfind_average_overhead = find_flag;
+  benchmark_timer_find_average_overhead = find_flag;
 }
@@ -3,6 +3,6 @@
  *  This file manages the benchmark timer used by the RTEMS Timing Test
  *  Suite.  Each measured time period is demarcated by calls to
- *  benchmark_timerinitialize() and benchmark_timerread().  benchmark_timerread() usually returns
- *  the number of microseconds since benchmark_timerinitialize() exitted.
+ *  benchmark_timer_initialize() and benchmark_timer_read().  benchmark_timer_read() usually returns
+ *  the number of microseconds since benchmark_timer_initialize() exitted.
  *
  *  NOTE: It is important that the timer start/stop overhead be
@@ -84,5 +84,5 @@
 
 /*
- *  The following controls the behavior of benchmark_timerread().
+ *  The following controls the behavior of benchmark_timer_read().
  *
  *  AVG_OVEREHAD is the overhead for starting and stopping the timer.  It
Index: c/src/lib/libbsp/sh/simsh4/timer/timer.c
===================================================================
--- c/src/lib/libbsp/sh/simsh4/timer/timer.c	(revision 6b2923cbc3d60fb3c204677bb0eed2afaedfa0c7)
+++ c/src/lib/libbsp/sh/simsh4/timer/timer.c	(revision 25c62b02bc8fc9e66c1735e562e91acaa94abbe3)
@@ -23,10 +23,10 @@
 uint32_t         Timer_interrupts;
 
-bool benchmark_timerfind_average_overhead;
+bool benchmark_timer_find_average_overhead;
 
 /* External assembler interrupt handler routine */
 extern rtems_isr timerisr(rtems_vector_number vector);
 
-/* benchmark_timerinitialize --
+/* benchmark_timer_initialize --
  *     Initialize timer 2 for accurate time measurement.
  *
@@ -38,5 +38,5 @@
  */
 void
-benchmark_timerinitialize(void)
+benchmark_timer_initialize(void)
 {
     return;
@@ -44,5 +44,5 @@
 
 /*
  *  The following controls the behavior of benchmark_timerread().
  *
  *  FIND_AVG_OVERHEAD *  instructs the routine to return the "raw" count.
@@ -60,5 +60,5 @@
 #define LEAST_VALID       1  /* Don't trust a clicks value lower than this */
 
-/* benchmark_timerread --
+/* benchmark_timer_read --
  *     Read timer value in microsecond units since timer start.
  *
@@ -70,28 +70,12 @@
  */
 int
-benchmark_timerread( void )
+benchmark_timer_read( void )
 {
     return 0;
 }
 
-/* benchmark_timerempty_function --
- *     Empty function call used in loops to measure basic cost of looping
- *     in Timing Test Suite.
- *
- * PARAMETERS:
- *     none
- *
- * RETURNS:
- *     RTEMS_SUCCESSFUL
- */
-rtems_status_code
-benchmark_timerempty_function(void)
-{
-    return RTEMS_SUCCESSFUL;
-}
-
-/* benchmark_timerdisable_subtracting_average_overhead --
+/* benchmark_timer_disable_subtracting_average_overhead --
  *     This routine is invoked by the "Check Timer" (tmck) test in the
  *     RTEMS Timing Test Suite. It makes the benchmark_timerread routine not
  *     subtract the overhead required to initialize and read the benchmark
  *     timer.
@@ -104,6 +88,6 @@
  */
 void
-benchmark_timerdisable_subtracting_average_overhead(bool find_flag)
+benchmark_timer_disable_subtracting_average_overhead(bool find_flag)
 {
-  benchmark_timerfind_average_overhead = find_flag;
+  benchmark_timer_find_average_overhead = find_flag;
 }
@@ -44,5 +44,5 @@
 
 /*
- *  The following controls the behavior of benchmark_timerread().
+ *  The following controls the behavior of benchmark_timer_read().
  *
  *  FIND_AVG_OVERHEAD *  instructs the routine to return the "raw" count.
@@ -70,28 +70,12 @@
  *     This routine is invoked by the "Check Timer" (tmck) test in the
- *     RTEMS Timing Test Suite. It makes the benchmark_timerread routine not
+ *     RTEMS Timing Test Suite. It makes the benchmark_timer_read routine not
  *     subtract the overhead required to initialize and read the benchmark
  *     timer.
